@@ -9,7 +9,7 @@ my %map2type = %Crypt::PWSafe3::Field::map2type;
 
 my %map2name = %Crypt::PWSafe3::Field::map2name;
 
-$Crypt::PWSafe3::Record::VERSION = '1.03';
+$Crypt::PWSafe3::Record::VERSION = '1.04';
 
 foreach my $field (keys %map2type ) {
   eval  qq(
@@ -137,7 +137,11 @@ sub addfield {
   #
   # add a field to the record
   my ($this, $field) = @_;
-  $this->{field}->{ $map2name{$field->type} } = $field;
+  my $name = $map2name{$field->type};
+  unless( defined($name) ) {
+      $name = $field->type; # consistent with Field->new
+  }
+  $this->{field}->{ $name } = $field;
 }
 
 =head1 NAME
